[prev in list] [next in list] [prev in thread] [next in thread] 

List:       pecl-cvs
Subject:    [PECL-CVS] com web/pecl: Don't expect TS only extensions to have NTS builds: src/PackageDll.php
From:       Christoph Michael Becker <cmb () php ! net>
Date:       2019-08-15 21:32:12
Message-ID: php-mail-bf70447389a9c21b4c7549b098da259c1185007284 () git ! php ! net
[Download RAW message or body]

Commit:    9d7578a3396c03e1fc58156f9f7c8753aab24f78
Author:    Christoph M. Becker <cmbecker69@gmx.de>         Thu, 15 Aug 2019 14:17:15 +0200
Parents:   41a33a996bf0917797ea5d3ac92f99f562637e4c
Branches:  master

Link:       http://git.php.net/?p=web/pecl.git;a=commitdiff;h=9d7578a3396c03e1fc58156f9f7c8753aab24f78

Log:
Don't expect TS only extensions to have NTS builds

For now we hard-code the list of extensions which are supposed to work
in thread-safe mode only.

Changed paths:
  M  src/PackageDll.php


Diff:
diff --git a/src/PackageDll.php b/src/PackageDll.php
index 7cb09ae..d3a8896 100644
--- a/src/PackageDll.php
+++ b/src/PackageDll.php
@@ -84,6 +84,8 @@ class PackageDll
         ],
     ];
 
+    private $ts_only_dlls = ['parallel', 'pthreads'];
+
     /**
      * Class constructor.
      */
@@ -211,7 +213,8 @@ class PackageDll
     }
 
     /**
      * Need always both ts/nts for each branch.
      */
     private function getZipFileList($name, $version)
     {
@@ -228,7 +231,9 @@ class PackageDll
                 if (!isset($ret[$branch][$set["arch"]])) {
                     $ret[$branch][$set["arch"]] = [];
                 }
-                $ret[$branch][$set["arch"]][] = strtolower($pref . "-nts-" . $suf);
+                if (!in_array($name, $this->ts_only_dlls, true)) {
+                    $ret[$branch][$set["arch"]][] = strtolower($pref . "-nts-" . $suf);
+                }
                 $ret[$branch][$set["arch"]][] = strtolower($pref . "-ts-" . $suf);
             }
         }
@@ -211,7 +213,8 @@ class PackageDll
 
     /**
-     * Need always both ts/nts for each branch.
+     * Need always both ts/nts for each branch,
+     * except for explicitly listed ts only exts.
      */
     private function getZipFileList($name, $version)


--
PECL CVS Mailing List
To unsubscribe, visit: http://www.php.net/unsub.php

[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic